==> mxee-0.12.1-py3-none-any.whl: mxee/helper/__init__.py <==
import pandas as pd
from openpyxl.utils import get_column_letter
from openpyxl.styles import Font
from rich.pretty import pprint as PP
import subprocess
import os
import pandas



def finder_expose(filename_or_path):
    subprocess.call("""/bin/bash -c 'open -R "%s"'""" % filename_or_path, shell=True)




def xlsx_sheetnames(filename:str):
    with pandas.ExcelFile(filename) as f:
        return(list(f.sheet_names))

def xlsx_rows(filename:str, sheetname:str, row_callback, context):
    df = pandas.read_excel(filename, dtype=str, header=None, sheet_name=sheetname)
    n_rows = len(df)
    n_cols = len(df.columns)

    hdr = []
    for col in range(0, n_cols):
        hdr.append(df.loc[0,col])

    # skip row0
    for r in range(1, n_rows):
        row = []
        row_assoc = {}
        for col in range(0, n_cols):
            row.append(df.loc[r,col])
            row_assoc[hdr[col]] = df.loc[r,col]
        row_callback(r+1, hdr, row, row_assoc, context)


def xlsx_out(filename:str, sheets:dict):
    """Simple Excel Writer.


    mxee.helper.xlsx_out(
        "test2.xlsx",
        sheets={
            'blatt1': {
                'data': [['A', 'B', 'C'],['120']],
                'cw':{'A': 50}
            }
        }
    )
"""
    try:
        with pd.ExcelWriter(filename) as ew:

            for k in sheets.keys():
                dat = sheets[k]['data']

                dfc = pd.DataFrame(dat) # dataframe current
                dfc.to_excel(ew, sheet_name=k, index=False, header=False)
            
                col_widths = {}
                if 'cw' in sheets[k].keys():
                    col_widths = sheets[k]['cw']

                for wdef_k in col_widths.keys():
                    ew.sheets[k].column_dimensions[wdef_k].width = col_widths[wdef_k]

                for header0_idx in range(0, len(dat[0])):
                    column_letter = get_column_letter(header0_idx+1)
                    ew.sheets[k][column_letter + "1"].font = Font(bold=True)
                
                ew.sheets[k].freeze_panes = ew.sheets[k]['A2']

    except Exception as e:
        import os
        os.unlink(filename)
        PP(e)

==> mxee-0.13.1-py3-none-any.whl: mxee/helper/__init__.py <==
import pandas as pd
from openpyxl.utils import get_column_letter
from openpyxl.styles import Font
from rich.pretty import pprint as PP
import subprocess
import os
import pandas



def finder_expose(filename_or_path):
    subprocess.call("""/bin/bash -c 'open -R "%s"'""" % filename_or_path, shell=True)




def xlsx_sheetnames(filename:str):
    with pandas.ExcelFile(filename) as f:
        return(list(f.sheet_names))

def xlsx_rows(filename:str, sheetname:str, row_callback, context):
    """row_callback(r, hdr, row, row_assoc, context).
    """
    df = pandas.read_excel(filename, dtype=str, header=None, sheet_name=sheetname, keep_default_na=False)
    n_rows = len(df)
    n_cols = len(df.columns)

    hdr = []
    for col in range(0, n_cols):
        hdr.append(df.loc[0,col])

    # skip row0
    for r in range(1, n_rows):
        row = []
        row_assoc = {}
        for col in range(0, n_cols):
            row.append(df.loc[r,col])
            row_assoc[hdr[col]] = df.loc[r,col]
        row_callback(r+1, hdr, row, row_assoc, context)


def xlsx_out(filename:str, sheets:dict):
    """Simple Excel Writer.


    mxee.helper.xlsx_out(
        "test2.xlsx",
        sheets={
            'blatt1': {
                'data': [['A', 'B', 'C'],['120']],
                'cw':{'A': 50}
            }
        }
    )
"""
    try:
        with pd.ExcelWriter(filename) as ew:

            for k in sheets.keys():
                dat = sheets[k]['data']

                dfc = pd.DataFrame(dat) # dataframe current
                dfc.to_excel(ew, sheet_name=k, index=False, header=False)
            
                col_widths = {}
                if 'cw' in sheets[k].keys():
                    col_widths = sheets[k]['cw']

                for wdef_k in col_widths.keys():
                    ew.sheets[k].column_dimensions[wdef_k].width = col_widths[wdef_k]

                for header0_idx in range(0, len(dat[0])):
                    column_letter = get_column_letter(header0_idx+1)
                    ew.sheets[k][column_letter + "1"].font = Font(bold=True)
                
                ew.sheets[k].freeze_panes = ew.sheets[k]['A2']

    except Exception as e:
        import os
        os.unlink(filename)
        PP(e)
